@@ -13,11 +13,11 @@ String::Copyright - Representation of text-based copyright statements
 
 =head1 VERSION
 
-Version 0.001
+Version 0.001001
 
 =cut
 
-our $VERSION = '0.001';
+our $VERSION = '0.001001';
 
 # Dependencies
 use Exporter 5.57 (qw/import/);
@@ -205,13 +205,10 @@ sub parse_string
 my $copyright_indicator_regex = qr!
 	(?:copyright(?:-holders?)? # The full word (or slightly more)
 		|copr\. # Legally-valid abbreviation
-		|\xc2\xa9 # Unicode copyright sign encoded in iso8859
-		|\x{00a9} # Unicode character COPYRIGHT SIGN
-		#|© # Unicode character COPYRIGHT SIGN
-		|[&]copy[;] # HTML ligature of sign
+		|© # Unicode character COPYRIGHT SIGN
 		|\(c\) # Legally-null representation of sign
 	)
-!lix;
+!ix;
 
 my $copyright_indicator_regex_with_capture
 	= qr!$copyright_indicator_regex(?::\s*|\s+)(\S.*)$!lix;
@@ -269,6 +266,31 @@ sub parse_line
 	return $copyright;
 }
 
+=head1 SEE ALSO
+
+=over 4
+
+=item *
+
+L<Encode>
+
+=back
+
+=head1 BUGS/CAVEATS/etc
+
+L<String::Copyright> operates on strings, not bytes.
+Data encoded as UTF-8, Latin1 or other formats
+need to be decoded to strings before use.
+
+Only ASCII characters and B<©> (copyright sign) are directly processed.
+
+If copyright sign is mis-detected
+or accents or multi-byte characters display wrong,
+then most likely the data was not decoded into a string.
+
+If ranges or lists of years are not tidied,
+then maybe it contained non-ASCII whitespace or digits.
+
 =head1 AUTHOR
 
 Jonas Smedegaard C<< <dr@jones.dk> >>
